@@ -2,6 +2,7 @@ from networktools.geo import (rad2deg, deg2rad, radius, sph_rotation_matrix,
                               llh2ecef, ecef2llh, ecef2neu)
 from networktools.time import timestamp, gps_week2time, gps_time
 from networktools.statistics import matrix_VCV, rotate
+from networktools.colorprint import gprint, rprint, bprint
 from data_geo.geojson import GeoJSONData
 import json
 import pika
@@ -67,13 +68,14 @@ class AMQPData(GeneralData):
             self.logger.exception("Error conectando canal Rabbitmq")
             raise e
         try:
+            bprint(f"Queue binding on connection: {self.queue_name} <-> source: {self.source}")
             if self.source:
                 self.channel.queue_declare(self.queue_name, 
                     durable=self.durable, 
                     arguments={'x-message-ttl' : self.ttl})
                 self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
             else:
-                self.queue_name = self.channel.queue_declare(exclusive=True)[0]
+                self.queue_name = self.channel.queue_declare("csn_ppp",exclusive=True)[0]
                 self.channel.queue_bind(self.queue_name, exchange=self.exchange)
         except Exception as e:
             self.logger.exception("Error declaring queue -> %s" % e)
